=========================
The ``lino_book`` package
=========================





.. image:: https://readthedocs.org/projects/lino/badge/?version=latest
   :target: http://lino.readthedocs.io/en/latest/?badge=latest
.. image:: https://coveralls.io/repos/github/lino-framework/book/badge.svg?branch=master
   :target: https://coveralls.io/github/lino-framework/book?branch=master
.. image:: https://travis-ci.org/lino-framework/book.svg?branch=stable
   :target: https://travis-ci.org/lino-framework/book?branch=stable
.. image:: https://img.shields.io/pypi/v/lino.svg
   :target: https://pypi.python.org/pypi/lino/
.. image:: https://img.shields.io/pypi/l/lino.svg
   :target: https://pypi.python.org/pypi/lino/

This is the code repository that contains (1) the Sphinx source files
of the Lino Book, (2) the ``lino_book`` Python package and (3) a test
suite with doctest-based tests for the Lino framework.

The **Lino Book** is the central documentation tree of the Lino
framework.  It is visible on `www.lino-framework.org
<http://www.lino-framework.org>`__ and on `lino.readthedocs.io
<http://lino.readthedocs.io>`__.

The ``lino_book`` Python package is a collection of small example Lino
applications used for educational and testing purposes.

The code repositories for the ``lino`` and ``lino_xl`` Python packages
have no documentation tree on their own and almost no unit tests, they
are tested and documented here.

Your feedback is welcome.  Our `community page
<http://www.lino-framework.org/community>`__ explains how to contact us.



